Sage Documentation
==================

Do not edit this file as its output is overridden by the template in the templates directory.

Do not delete this line as it enables MathJax in the webpage generated from this file: :math:`e^{\pi i}+1=0`.
